# CA® Endevor SCM Plug-in for Zowe CLI

<img src="images/Zowe_ConformanceBadge_cli.png" width=25% alt="Zowe Conformance Badge"/>

This repository contains a command line interface (CLI) that interacts with CA Endevor SCM. You can build it as either an independent CLI application or as a plug-in that can be installed into an existing application, such as Brightside.

The CA Endevor application is built on the [Imperative Framework](**REMOVED**).

# Use Cases
You can use the CA® Endevor SCM Plug-in for Zowe CLI to perform the following tasks without having to leave the ZOWE CLI interface:
  Check out source code that resides in CA Endevor SCM, and work with the code in a non-mainframe IDE or editor such as Sublime,           Visual Studio Code, or IntelliJ IDEA

  Interact with CA Endevor SCM application lifecycle actions, allowing easy scripting from CI/CD pipelines.
  Build code and integrate CA Endevor SCM element code into wider packages.
  Access multiple data sources within a single CLI, enabling quick comparison and inclusion of data.
  Interact with CA Endevor SCM for basic SCM inventory, which provides an alternative experience for end users, which enables easier       learning and adoption.
  Build checked-in source for use in unit and functional test environments.
  Approve workflows in response to events in other DevOps tools.

# Prerequisites
Before you install the plug-in, it is important to ensure that you meet the following prerequisites:
  Zowe CLI installed and configured.
  CA Endevor SCM instance with the CA Endevor SCM Web Services component installed

# Build the Plug-in from Source and Link CA Endevor Application
Build plug-in from source and then link it to your Endevor application.

**Follow these steps:**

1. Clone this repository to your PC as follws:
  Issue git clone https://github.com/your-username/your-repository Press Enter.
  The local clone is created.
2. In a command line, issue `cd [relative path]/endevor`
3. Issue `npm install`
4. Issue `npm run build`
5. Issue `npm link`

# Install the CA® Endevor SCM Plug-in for Zowe CLI
Issue the following command:

```bash
zowe plugins install <path_to_endevor_directory>
```

# Examples
The following examples show how Imperative CLI Framework features are implemented in the CA Endevor CLI.

* [Default Help](#default-help)
* [List Regions](#list-regions)

## Default Help

**` zowe endevor --help`**

     DESCRIPTION
     -----------

       CA Endevor SCM plug-in for listing Endevor environment information, working
       with elements and packages located in specified Endevor instance.

     USAGE
     -----

       zowe endevor [group]

     COMMANDS
     --------

       add            Add an Element into CA Endevor SCM.
       approve | aprv Approve a Package in CA Endevor SCM.
       backin         Backin a Package in CA Endevor SCM.
       backout        Backout a Package in CA Endevor SCM.
       cast           Cast a Package in CA Endevor SCM.
       create         Create a Package in CA Endevor SCM.
       delete | del   Delete an Element or a Package in CA Endevor SCM.
       deny           Deny a Package in CA Endevor SCM.
       execute        Execute a Package in CA Endevor SCM.
       generate | gen Generate an Element in CA Endevor SCM.
       list           List instances, elements, types, packages and inventory
                      locations in CA Endevor SCM.
       move | mv      Move an Element in CA Endevor SCM.
       print | p      Print an Element or a Component in CA Endevor SCM.
       reset          Reset a Package in CA Endevor SCM.
       retrieve | ret Retrieve an Element in CA Endevor SCM.
       signin | si    Signin an Element in CA Endevor SCM.
       submit         Submit a Package or a SCL file in CA Endevor SCM.
       transfer | tr  Transfer an Element in CA Endevor SCM.
       update         Update an Element or a Package in CA Endevor SCM.

     GLOBAL OPTIONS
     --------------

     --response-format-json  | --rfj (flag) (optional)

        Produce the command response as a JSON document

     --help  | -h (flag) (optional)

        Display help text

## List Regions

**` zowe endevor list regions --hostname ca31 --port 47614`**

      [INFO] Running on host: ca31:47614 instance: *
      description                name     jobName  hostName userId
      Endevor demo               CMEWTEST CMEWTEST A31SENF  ENDEVOR
      CA Endevor SCM Web Service CMEWQA02 CMEWQA02 A31SENF  ENDEVOR
      Endevor demo               STCNPOOL WEBSMFNE A31SENF  ENDEVOR
      Endevor demo               STCP1142 CMEWTEST A31SENF  ENDEVOR
      CA Endevor SCM Web Service WEBSALC  WEBSALC  A31SENF  BERBE02
      Endevor demo               WEBSJPN  WEBSMFNE A31SENF  ENDEVOR
      Endevor demo               CMEWMV01 CMEWMV01 A31SENF  ENDEVOR

# Uninstall the Plug-in

Issue the following command:

```bash
zowe plugins uninstall @broadcom/endevor-for-zowe-cli
```

