"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const endevor_for_zowe_cli_1 = require("@broadcom/endevor-for-zowe-cli");
const BrowseElement_1 = require("../../../commands/BrowseElement");
const globals_1 = require("../../../globals");
const Element_1 = require("../../../model/Element");
const Repository_1 = require("../../../model/Repository");
const EndevorNodes_1 = require("../../../ui/tree/EndevorNodes");
// Explicitly show NodeJS how to find VSCode (required for Jest)
process.vscode = vscode;
describe('Test function browseElement', () => {
    // Mock vscode's progress function
    const mockWithProgress = jest.fn();
    Object.defineProperty(vscode, 'ProgressLocation', {
        value: { Notification: 15 },
    });
    Object.defineProperty(vscode.window, 'withProgress', {
        value: mockWithProgress,
    });
    // Mock the elements, nodes, and repo
    const mockSetupPrintRequest = jest.fn();
    const mockPrintElementComponents = jest.fn();
    Object.defineProperty(endevor_for_zowe_cli_1.PrintElementComponents, 'setupPrintRequest', {
        value: mockSetupPrintRequest,
    });
    Object.defineProperty(endevor_for_zowe_cli_1.PrintElementComponents, 'printElementComponents', {
        value: mockPrintElementComponents,
    });
    const testRepo = new Repository_1.Repository('testRepo', 'https://example.com:1234', 'testUser', 'testPass', 'testRepo', 'testConnLabel');
    const testIElement = {
        elmName: 'elmTest1',
        fullElmName: 'elmTest1',
        elmVVLL: '1100',
        envName: 'envTest',
        sysName: 'sysTest',
        sbsName: 'sbsTest',
        stgNum: '1',
        typeName: 'COBOL',
    };
    const testElement = new Element_1.Element(testRepo, testIElement);
    const testQualifier = {
        element: testElement.elmName,
        env: 'envTest',
        stage: '1',
        subsystem: 'sbsTest',
        system: 'sysTest',
        type: 'COBOL',
    };
    const testEndevorElementNode = new EndevorNodes_1.EndevorElementNode(testElement, testQualifier);
    // All spies are listed here
    const openDocumentSpy = jest.spyOn(vscode.workspace, 'openTextDocument');
    const loggerErrorSpy = jest.spyOn(globals_1.logger, 'error');
    beforeEach(() => {
        // Redefine mocks, because we clear them after each run
        mockWithProgress.mockImplementation((progLocation, callback) => __awaiter(void 0, void 0, void 0, function* () {
            const ProgressLocation = {
                Notification: 15,
                report: jest.fn(),
            };
            return yield callback(ProgressLocation);
        }));
    });
    afterEach(() => {
        // This is here to clear the spies
        jest.clearAllMocks();
    });
    test("Should show an element's components in the text editor", () => __awaiter(void 0, void 0, void 0, function* () {
        mockPrintElementComponents.mockReturnValueOnce({ data: 'test file data' });
        yield BrowseElement_1.browseElement(testEndevorElementNode);
        expect(openDocumentSpy).toBeCalledWith({ content: 'test file data' });
    }));
    test("Should throw an error, if element's components cannot be retrieved from Endevor", () => __awaiter(void 0, void 0, void 0, function* () {
        mockPrintElementComponents.mockRejectedValueOnce({
            cancelled: false,
            error: 'Test error!',
        });
        yield BrowseElement_1.browseElement(testEndevorElementNode);
        expect(loggerErrorSpy).toBeCalledWith('Test error!');
    }));
});
//# sourceMappingURL=browseElement-test.js.map