"use strict";
/* eslint-disable @typescript-eslint/no-explicit-any */
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const vscode = require("vscode");
const AddFilter_1 = require("./commands/AddFilter");
const BrowseElement_1 = require("./commands/BrowseElement");
const Common_1 = require("./commands/Common");
const DeleteFilter_1 = require("./commands/DeleteFilter");
const DeleteHost_1 = require("./commands/DeleteHost");
const DeleteConnection_1 = require("./commands/DeleteConnection");
const EditFilter_1 = require("./commands/EditFilter");
const HostDialogs_1 = require("./commands/HostDialogs");
const RetrieveElement_1 = require("./commands/RetrieveElement");
const RetrieveElementWithDependencies_1 = require("./commands/RetrieveElementWithDependencies");
const EndevorController_1 = require("./EndevorController");
const RetrieveElementService_1 = require("./service/RetrieveElementService");
const SettingsFacade_1 = require("./service/SettingsFacade");
const EndevorDataProvider_1 = require("./ui/tree/EndevorDataProvider");
const utils_1 = require("./utils");
const imperative_1 = require("@zowe/imperative");
const path = require("path");
const Profiles_1 = require("./service/Profiles");
const globals_1 = require("./globals");
let log;
function activate(context) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            // Initialize Imperative Logger and load Profiles
            // eslint-disable-next-line @typescript-eslint/no-var-requires
            const loggerConfig = require(path.join(context.extensionPath, 'log4jsconfig.json'));
            loggerConfig.log4jsConfig.appenders.default.filename = path.join(context.extensionPath, 'logs', 'imperative.log');
            loggerConfig.log4jsConfig.appenders.imperative.filename = path.join(context.extensionPath, 'logs', 'imperative.log');
            loggerConfig.log4jsConfig.appenders.app.filename = path.join(context.extensionPath, 'logs', 'zowe.log');
            imperative_1.Logger.initLogger(loggerConfig);
            log = imperative_1.Logger.getAppLogger();
            log.debug('Initialized logger from VSCode extension');
        }
        catch (err) {
            log.error('Error encountered while activating and initializing logger! ' +
                JSON.stringify(err));
            globals_1.logger.error(err.message);
        }
        yield Profiles_1.Profiles.createInstance(log);
        const endevorDataProvider = yield EndevorDataProvider_1.createEndevorTree(log);
        const retrieveElementService = new RetrieveElementService_1.RetrieveElementService();
        EndevorController_1.EndevorController.instance.loadRepositories();
        const endevorExplorerView = vscode.window.createTreeView('endevorExplorer', {
            treeDataProvider: endevorDataProvider,
        });
        endevorExplorerView.onDidCollapseElement((event) => {
            event.element.collapsibleState = vscode.TreeItemCollapsibleState.Collapsed;
        });
        endevorExplorerView.onDidExpandElement((event) => {
            event.element.collapsibleState = vscode.TreeItemCollapsibleState.Expanded;
        });
        context.subscriptions.push(endevorExplorerView);
        try {
            endevorExplorerView.onDidChangeSelection(() => {
                vscode.commands.executeCommand('setContext', 'multipleSelection', utils_1.multipleElementsSelected(endevorExplorerView.selection));
            });
        }
        catch (ignore) {
            console.warn(ignore);
            vscode.commands.executeCommand('setContext', 'multipleSelection', false);
        }
        context.subscriptions.push(vscode.commands.registerCommand('endevorexplorer.newHost', (arg) => {
            HostDialogs_1.HostDialogs.addHost(arg).then(() => {
                vscode.commands.executeCommand('endevorexplorer.refreshHosts');
            });
        }));
        context.subscriptions.push(vscode.commands.registerCommand('endevorexplorer.newConnection', () => {
            HostDialogs_1.HostDialogs.addConnection().then(() => {
                vscode.commands.executeCommand('endevorexplorer.refreshHosts');
            });
        }));
        context.subscriptions.push(vscode.commands.registerCommand('endevorexplorer.deleteConnection', DeleteConnection_1.deleteConnection));
        context.subscriptions.push(vscode.commands.registerCommand('endevorexplorer.updateHost', (arg) => {
            if (arg.contextValue === 'repository') {
                HostDialogs_1.HostDialogs.editHost(arg);
            }
        }));
        context.subscriptions.push(vscode.commands.registerCommand('endevorexplorer.refreshRepo', (arg) => {
            EndevorController_1.EndevorController.instance.updateNeedReloadInTree(true, arg);
            endevorDataProvider.refresh();
        }));
        context.subscriptions.push(vscode.commands.registerCommand('endevorexplorer.refreshHosts', () => {
            EndevorController_1.EndevorController.instance.updateNeedReloadInTree(true, EndevorController_1.EndevorController.instance.rootNode);
            endevorDataProvider.refresh();
        }));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.AddFilter, AddFilter_1.addFilter));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.EditFilter, EditFilter_1.editFilter));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.DeleteFilter, DeleteFilter_1.deleteFilter));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.DeleteHost, DeleteHost_1.deleteHost));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.RetrieveElement, (arg) => {
            RetrieveElement_1.retrieveElement(arg, endevorExplorerView.selection, retrieveElementService);
        }));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.RetrieveWithDependencies, (arg) => {
            RetrieveElementWithDependencies_1.retrieveWithDependencies(arg, retrieveElementService);
        }));
        context.subscriptions.push(vscode.commands.registerCommand(Common_1.Commands.BrowseElement, BrowseElement_1.browseElement));
        context.subscriptions.push(vscode.workspace.onDidChangeConfiguration((event) => {
            if (event.affectsConfiguration(SettingsFacade_1.HOST_SETTINGS_KEY)) {
                endevorDataProvider.refresh();
                vscode.commands.executeCommand('endevorexplorer.refreshHosts');
            }
        }));
    });
}
exports.activate = activate;
// eslint-disable-next-line @typescript-eslint/no-empty-function
function deactivate() { }
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map