"use strict";
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.System = void 0;
const EndevorEntity_1 = require("./EndevorEntity");
class System extends EndevorEntity_1.EndevorEntity {
    constructor(repo, system) {
        super();
        this.envName = system.envName;
        this.sysName = system.sysName;
        this.subsystems = new Map();
        this.types = new Map();
        this.repository = repo;
    }
    loadSubSystems(newSubSystems, append) {
        if (!append) {
            this.subsystems = new Map();
        }
        newSubSystems.forEach((subsys) => {
            this.subsystems.set(subsys.sbsName, subsys);
        });
    }
    loadTypes(newTypes, append) {
        if (!append) {
            this.types = new Map();
        }
        newTypes.forEach((type) => {
            this.types.set(type.typeName, type);
        });
    }
    findType(typeName) {
        return this.types.get(typeName);
    }
    getTypes() {
        return Array.from(this.types.values());
    }
    findSubSystem(subsysName) {
        return this.subsystems.get(subsysName);
    }
    getSubSystems() {
        return Array.from(this.subsystems.values());
    }
    getName() {
        return this.sysName;
    }
    getDescription() {
        return '';
    }
    getSysName() {
        return this.sysName;
    }
    getRepository() {
        return this.repository;
    }
}
exports.System = System;
//# sourceMappingURL=System.js.map