"use strict";
/* eslint-disable no-case-declarations */
/* eslint-disable @typescript-eslint/consistent-type-assertions */
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EndevorDataProvider = exports.createEndevorTree = void 0;
const vscode = require("vscode");
const EndevorNodes_1 = require("./EndevorNodes");
const EndevorController_1 = require("../../EndevorController");
const Profiles_1 = require("../../service/Profiles");
const Connection_1 = require("../../model/Connection");
const globals_1 = require("../../globals");
// eslint-disable-next-line @typescript-eslint/no-unused-vars
function createEndevorTree(log) {
    return __awaiter(this, void 0, void 0, function* () {
        const tree = new EndevorDataProvider();
        yield tree.addSession();
        return tree;
    });
}
exports.createEndevorTree = createEndevorTree;
class EndevorDataProvider {
    constructor() {
        this._sessionNodes = [];
        this._onDidChangeTreeData = new vscode.EventEmitter();
        this.onDidChangeTreeData = this._onDidChangeTreeData.event;
    }
    getTreeItem(element) {
        return element;
    }
    addSession(sessionName) {
        globals_1.logger.trace(`Adding <${sessionName}> session to the tree.`);
        if (sessionName) {
            const endevorProfile = Profiles_1.Profiles.getInstance().loadNamedProfile(sessionName);
            if (endevorProfile) {
                this.addSingleSession(endevorProfile);
            }
            else {
                globals_1.logger.error(`Profile not found for session <${sessionName}>.`);
            }
        }
        else {
            const endevorProfiles = Profiles_1.Profiles.getInstance().allProfiles;
            for (const endevorProfile of endevorProfiles) {
                if (this._sessionNodes.find((tempNode) => tempNode.label && tempNode.label.trim() === endevorProfile.name)) {
                    continue;
                }
            }
            const defaultProfile = Profiles_1.Profiles.getInstance().defaultProfile;
            if (this._sessionNodes.length === 0 && defaultProfile) {
                this.addSingleSession(defaultProfile);
            }
        }
        this.refresh();
    }
    getChildren(node) {
        if (!node) {
            const root = EndevorController_1.EndevorController.instance.rootNode;
            if (!root.needReload) {
                return Promise.resolve([new EndevorNodes_1.NewConnectionButton(), ...root.children]);
            }
            const connections = EndevorController_1.EndevorController.instance.getConnections();
            const newChildren = [];
            connections.forEach((connection) => {
                const newConnectionNode = new EndevorNodes_1.EndevorNode(connection);
                let foundConnection;
                const connectionName = connection.getName();
                if (connectionName) {
                    foundConnection = EndevorController_1.EndevorController.instance.findNodeByConnectionName(connectionName);
                }
                if (foundConnection && foundConnection.needReload) {
                    newConnectionNode.children = foundConnection.children;
                    newConnectionNode.needReload = false;
                    newConnectionNode.collapsibleState = foundConnection.collapsibleState;
                }
                newChildren.push(newConnectionNode);
            });
            root.needReload = false;
            root.children = newChildren;
            return Promise.resolve([new EndevorNodes_1.NewConnectionButton(), ...newChildren]);
        }
        switch (node.contextValue) {
            case 'connection':
                return Promise.resolve(node.children);
            case 'repository':
                const repo = this.getNodeRepository(node);
                if (!repo) {
                    return Promise.resolve([]);
                }
                if (!node.needReload) {
                    return Promise.resolve(node.children);
                }
                return new Promise((resolve) => {
                    const resultNodes = [];
                    resultNodes.push(new EndevorNodes_1.EndevorBrowsingNode('Filters', repo));
                    resultNodes.push(new EndevorNodes_1.EndevorBrowsingNode('Map', repo));
                    node.children = resultNodes;
                    node.needReload = false;
                    resolve(resultNodes);
                });
            case 'filters':
            case 'map':
                return node.lazyLoadChildren();
            case 'filter':
                return node.lazyLoadChildren();
            case 'filterPathNode':
                return node.lazyLoadChildren();
            case 'environment':
                return node.lazyLoadChildren();
            case 'stage':
                return node.lazyLoadChildren();
            case 'system':
                return node.lazyLoadChildren();
            case 'subsystem':
                return node.lazyLoadChildren();
            case 'type':
                return node.lazyLoadChildren();
            default:
                return Promise.resolve([]);
        }
    }
    refresh() {
        this._onDidChangeTreeData.fire(null);
    }
    getNodeRepository(node) {
        let repo = node.getRepository();
        if (node instanceof EndevorNodes_1.EndevorBrowsingNode) {
            repo = node.getRepository();
        }
        return repo;
    }
    addSingleSession(endevorProfile) {
        return __awaiter(this, void 0, void 0, function* () {
            globals_1.logger.trace(`Loading profile <${endevorProfile.name}>.`);
            if (this._sessionNodes.find((tempNode) => tempNode.label && tempNode.label.trim() === endevorProfile.name)) {
                return;
            }
            const session = yield Profiles_1.Profiles.getInstance().createBasicEndevorSession(endevorProfile.profile);
            globals_1.logger.trace(`Session created: ${JSON.stringify(session)}`);
            const node = new EndevorNodes_1.ConnectionNode(session, endevorProfile.name);
            EndevorController_1.EndevorController.instance.addConnection(new Connection_1.Connection(endevorProfile));
            this._sessionNodes.push(node);
        });
    }
}
exports.EndevorDataProvider = EndevorDataProvider;
//# sourceMappingURL=EndevorDataProvider.js.map