"use strict";
/* eslint-disable no-case-declarations */
/*
 * Copyright (c) 2020 Broadcom.
 * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Broadcom, Inc. - initial API and implementation
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HostPanel = void 0;
const endevor_for_zowe_cli_1 = require("@broadcom/endevor-for-zowe-cli");
const fs = require("fs");
const path = require("path");
const vscode = require("vscode");
const EndevorController_1 = require("../../EndevorController");
const Repository_1 = require("../../model/Repository");
const utils = require("../../utils");
const globals_1 = require("../../globals");
class HostPanel {
    static createOrShow(context, repo) {
        if (!(vscode.workspace.workspaceFolders &&
            vscode.workspace.workspaceFolders.length > 0)) {
            globals_1.logger.error('Specify a workspace before creating a repository.');
            return;
        }
        const panel = vscode.window.createWebviewPanel(HostPanel.viewType, repo ? repo.getName() : 'New Endevor Host', vscode.ViewColumn.One, {
            enableScripts: true,
            retainContextWhenHidden: true,
        });
        const filePath = vscode.Uri.file(path.join(context.extensionPath, 'resources', 'hostpanel.html'));
        panel.webview.html = fs
            .readFileSync(filePath.fsPath, 'utf8')
            .split('${name}')
            .join(repo ? repo.getName() : 'New host');
        panel.webview.onDidReceiveMessage((message) => __awaiter(this, void 0, void 0, function* () {
            switch (message.command) {
                case 'update':
                    const name = message.data.name;
                    const url = message.data.url;
                    const username = message.data.username;
                    const password = message.data.password;
                    const datasource = message.data.configuration;
                    const targetRepo = new Repository_1.Repository(name, url, username, password, datasource, '');
                    EndevorController_1.EndevorController.instance.addRepository(targetRepo, '');
                    EndevorController_1.EndevorController.instance.updateSettings();
                    panel.dispose();
                    break;
                case 'configuration':
                    const restUrl = message.data.url;
                    const newRepo = new Repository_1.Repository('', restUrl, '', '', '', '');
                    try {
                        const session = yield utils.buildSession(newRepo);
                        const datasources = yield endevor_for_zowe_cli_1.ListInstance.listInstance(session);
                        const dsNames = [];
                        for (const ds of datasources) {
                            // eslint-disable-next-line @typescript-eslint/consistent-type-assertions
                            dsNames.push(ds.name);
                        }
                        dsNames.sort();
                        panel.webview.postMessage({ data: dsNames });
                    }
                    catch (error) {
                        panel.webview.postMessage({ data: [] });
                    }
                    break;
            }
        }), undefined, context.subscriptions);
    }
    static editHost(context, repo) {
        const panel = vscode.window.createWebviewPanel(HostPanel.viewType, repo ? repo.getName() : 'New Endevor Host', vscode.ViewColumn.One, {
            enableScripts: true,
            retainContextWhenHidden: true,
        });
        const filePath = vscode.Uri.file(path.join(context.extensionPath, 'resources', 'edithost.html'));
        panel.webview.html = fs
            .readFileSync(filePath.fsPath, 'utf8')
            .split('${name}')
            // eslint-disable-next-line no-useless-escape
            .join(repo.getName().replace(/\"/g, '&quot;'))
            .split('${username}')
            .join(repo ? repo.getUsername() : '')
            .split('${url}')
            .join(repo ? repo.getUrl() : '')
            .split('${datasource}')
            .join(repo ? repo.getDatasource() : '')
            .split('${password}')
            .join(repo.getPassword() !== undefined ? repo.getPassword() : '');
        panel.webview.onDidReceiveMessage((message) => {
            if (message.command !== 'editHost') {
                return;
            }
            const name = message.data.name;
            const username = message.data.username;
            const password = message.data.password;
            repo.setName(name);
            repo.setUsername(username);
            repo.setPassword(password);
            EndevorController_1.EndevorController.instance.updateSettings();
            panel.dispose();
        }, undefined, context.subscriptions);
    }
}
exports.HostPanel = HostPanel;
HostPanel.viewType = 'endevorHostPanel';
//# sourceMappingURL=HostPanel.js.map